@@ -1,11 +1,10 @@
 package IIIF::Magick;
 use 5.014001;
 
-our $VERSION = "0.04";
+our $VERSION = "0.05";
 
-use Exporter;
-our @ISA    = qw(Exporter);
-our @EXPORT = qw(info available convert args);
+use parent 'Exporter';
+our @EXPORT = qw(info available convert convert_command convert_args);
 
 use IPC::Cmd qw(can_run);
 use List::Util qw(min);
@@ -18,9 +17,10 @@ sub info {
     my $file = shift;
 
     -f $file or die "$file: No such file\n";
-    my $out = run( qw(identify -format %Wx%H), $file );
+    my $cmd = join ' ', map shell_quote($_), qw(identify -format %Wx%H), $file;
 
-    ( $out =~ /^(\d+)x(\d+)$/ ) or die "$file: Failed to get image dimensions";
+    ( `$cmd` =~ /^(\d+)x(\d+)$/ )
+      or die "$file: Failed to get image dimensions";
 
     return {
         '@context' => 'http://iiif.io/api/image/3/context.json',
@@ -32,18 +32,18 @@ sub info {
     };
 }
 
-sub args {
-    my ( $req, $file ) = @_;
-
+sub convert_args {
+    my $req = shift;
     my @args;
 
     # apply region
     if ( $req->{region} eq 'square' ) {
-        my $info = info($file);
-        if ( $info->{width} ne $info->{height} ) {
-            my $size = min( $info->{width}, $info->{height} );
-            @args = ( qw(-gravity center -crop), "${size}x${size}+0+0" );
-        }
+
+     # could be simpler in ImageMagick 7:
+     # push @args, qw(-gravity center -crop), "%[fx:w>h?h:w]x%[fx:w>h?h:w]+0+0";
+        push @args, qw(-set option:distort:viewport
+          %[fx:w>h?h:w]x%[fx:w>h?h:w]+%[fx:w>h?(w-h)/2:0]+%[fx:w>h?0:(h-w)/2]
+          -filter point -distort SRT 0 +repage);
     }
     elsif ( my $region_px = $req->{region_px} ) {
         my ( $x, $y, $w, $h ) = @$region_px;
@@ -52,11 +52,14 @@ sub args {
     elsif ( my $region_pct = $req->{region_pct} ) {
         my ( $x, $y, $w, $h ) = @$region_pct;
 
-        my $info = info($file);
-        $x = int( $x * $info->{width} / 100 + 0.5 );
-        $y = int( $y * $info->{height} / 100 + 0.5 );
+        if ( $x || $y ) {
+            my $px = $x / 100;
+            my $py = $y / 100;
+            push @args, '-set', 'page', "-%[fx:w*$px]-%[fx:h*$py]";
+        }
 
-        @args = ( '-crop', "${w}x$h%+$x+$y" );
+        # could also be simpler in ImageMagick 7
+        push @args, '-crop', "${w}x$h%+0+0";
     }
 
     # apply size
@@ -66,22 +69,18 @@ sub args {
     elsif ( $req->{size_px} ) {
         my ( $x, $y ) = @{ $req->{size_px} };
 
-        # TODO: respect upscale
-
-        if ( $x && $y ) {
-            if ( $req->{ratio} ) {
-                push @args, '-resize', "${x}x$y";
-            }
-            else {
-                push @args, '-resize', "${x}x$y!";
-            }
-        }
-        elsif ( $x && !$y ) {
+        if ( $x && !$y ) {
             push @args, '-resize', "${x}";
         }
         elsif ( !$x && $y ) {
             push @args, '-resize', "x${y}";
         }
+        elsif ( $req->{ratio} ) {
+            push @args, '-resize', "${x}x$y";
+        }
+        else {
+            push @args, '-resize', "${x}x$y!";
+        }
     }
 
     # apply rotation
@@ -101,43 +100,43 @@ sub args {
         push @args, qw(-monochrome -colors 2);
     }
 
-    push @args, $file if defined $file;
-
     return @args;
 }
 
+sub convert_command {
+    my ( $req, $in, $out ) = splice @_, 0, 3;
+
+    my @cmd = ( 'convert', @_, convert_args($req) );
+    push @cmd, $in  if defined $in  and $in ne '';
+    push @cmd, $out if defined $out and $out ne '';
+    unshift @cmd, "magick" if can_run("magick");
+
+    return join ' ', map shell_quote($_), @cmd;
+}
+
+sub convert {
+    my $command = convert_command(@_);
+    qx{$command};
+    return !$?;
+}
+
 # adopted from <https://metacpan.org/release/ShellQuote-Any-Tiny>
 sub shell_quote {
     my $arg = shift;
 
     if ( $^O eq 'MSWin32' ) {
-        if ( $arg =~ /\A\w+\z/ ) {
-            return $arg;
+        if ( $arg !~ /\A[\w_+-]+\z/ ) {
+            $arg =~ s/\\(?=\\*(?:"|$))/\\\\/g;
+            $arg =~ s/"/\\"/g;
+            return qq("$arg");
         }
-        $arg =~ s/\\(?=\\*(?:"|$))/\\\\/g;
-        $arg =~ s/"/\\"/g;
-        return qq("$arg");
     }
-    else {
-        if ( $arg =~ qr{\A[\w,_+/.-]+\z} ) {
-            return $arg;
-        }
+    elsif ( $arg !~ qr{\A[\w,_+/.-]+\z} ) {
         $arg =~ s/'/'"'"'/g;
         return "'$arg'";
     }
-}
 
-sub convert {
-    my ( $req, $in, $out, @args ) = @_;
-
-    run( 'convert', @args, args( $req, $in ), $out );
-    return !$?;
-}
-
-sub run {
-    unshift @_, "magick" if can_run("magick");
-    my $command = join ' ', map &shell_quote, @_;
-    qx{$command};
+    return $arg;
 }
 
 1;
@@ -180,9 +179,26 @@ Convert an image file as specified with a L<IIIF::Request> into an output file.
 Returns true on success. Additional arguments are prepended to the call of
 ImageMagick's C<convert>.
 
-=head2 args( $request, $file )
+Requires at least ImageMagick 6.9.
+
+=head2 convert_command( $request, $file, $output [, @args ] )
+
+Get a shell-quoted command to convert an image with a L<IIIF::Request>.
+
+=head2 convert_args( $request )
 
 Get the list of command line arguments to C<convert> to transform an image file
 as specified via a L<IIIF::Request>.
 
+=head2 LIMITATIONS
+
+The upscale option of L<size|https://iiif.io/api/image/3.0/#42-size> parameter
+is ignored: size C<^max> will not upscale the image as the resulting size
+depends on additional variables C<maxWidth>, C<maxHeight>, C<maxArea>. 
+
+The IIIF Image API Request is not validated before processing. Sizes larger
+than the selected region will therefore always result in an upscaled image.
+Use method C<canonical> of L<IIIF::Request> to filter out such invalid
+requests.
+
 =cut
